# Generated by Django 2.2.4 on 2019-10-16 14:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0012_auto_20191016_1106'),
    ]

    operations = [
        migrations.DeleteModel(
            name='FilterAdapter',
        ),
    ]
